import { geoOrthographic, geoPath, geoGraticule } from 'd3';

const projection = geoOrthographic();
const path = geoPath(projection);
const graticule = geoGraticule();

export const map = (
  selection,
  {
    worldAtlasData,
    submarineCablesData,
    rotation,
    scale,
    translation,
  },
) => {
  projection
    .rotate(rotation)
    .scale(scale)
    .translate(translation);

  selection
    .selectAll('path.outline')
    .data([{ type: 'Sphere' }])
    .join('path')
    .attr('class', 'outline')
    .attr('d', path)
    .attr('fill', 'none')
    .attr('stroke', 'black')
    .attr('stroke-width', 2);

  selection
    .selectAll('path.graticule')
    .data([null])
    .join('path')
    .attr('class', 'graticule')
    .attr('d', path(graticule()))
    .attr('fill', 'none')
    .attr('stroke', '#BBB')
    .attr('stroke-width', 0.5);

  selection
    .selectAll('path.country')
    .data(worldAtlasData.features)
    .join('path')
    .attr('d', path)
    .attr('class', 'country')
    .attr('stroke', 'white')
    .attr('stroke-width', 0.5);

  selection
    .selectAll('path.cable')
    .data(submarineCablesData.features)
    .join('path')
    .attr('class', 'cable')
    .attr('d', path)
    .attr('fill', 'none')
    .attr('stroke', (d) => d.properties.color)
    .attr('stroke-width', 157 / 100);
  // .attr('stroke', '#0131A2');
};
